package site

import (
	"github.com/astaxie/beego"
	"SCRM/controllers"
	"fmt"
	"encoding/json"
	"SCRM/utils"
	"SCRM/enums"
	"strconv"
	"SCRM/service/site_service"
	"SCRM/models"
	"time"
)
func siteRouters() {
	beego.Router("/api/site/savehispital",&Microwebsite{},"Post:SaveHispital")
	beego.Router("/api/site/addoffices",&Microwebsite{},"Post:AddOffices")
	beego.Router("/api/site/adddoctor",&Microwebsite{},"Post:AddDoctor")
	beego.Router("/api/site/adddoctorinfo",&Microwebsite{},"Post:AddDoctorInfo")
}

type Microwebsite struct {
	controllers.BaseAuthAPIController
}

//医院介绍
func (this *Microwebsite) SaveHispital()  {
	adminUserInfo := this.GetAdminUserInfo()
	userOrgID := int64(adminUserInfo.CurrentOrgId)
	dataBody := make(map[string]interface{}, 0)
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &dataBody)
	fmt.Println("错误是什么呢",err)
    fmt.Println("机构ID",userOrgID)
	if err != nil {
		utils.ErrorLog(err.Error())
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误")
		return
	}

	title := dataBody["title"].(string)
	if len(title) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "模块标题不能为空")
		return
	}
	fmt.Println("姓名:",title)
	sort := dataBody["sort"].(string)
	if len(sort) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "排序值不能为空")
		return
	}
	sortt, err := strconv.ParseInt(sort, 10, 64)
	fmt.Println("排序:",sortt)
	introduction := dataBody["introduction"].(string)
	if len(introduction) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "医院介绍不能为空")
		return
	}
	fmt.Println("姓名是什么?",title,"排序是什么",sortt,"医院介绍不能为空",introduction)

	hospital := models.SgjPatientHospital{
		Title:        title,
		Sort:         sortt,
		Introduction: introduction,
		UserOrgId:userOrgID,
		Ctime:time.Now().Unix(),
	}
	err = site_service.AddHispital(hospital)
	if err !=nil{
		this.ServeFailJsonSend(enums.ErrorCodeDataException, "添加医院失败")
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"hospital":hospital,
	})
}

//添加科室
func  (this *Microwebsite) AddOffices()  {
	adminUserInfo := this.GetAdminUserInfo()
	userOrgID := int64(adminUserInfo.CurrentOrgId)
	dataBody := make(map[string]interface{}, 0)
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &dataBody)
	fmt.Println("错误是什么呢",err)
	fmt.Println("机构ID",userOrgID)
	if err != nil {
		utils.ErrorLog(err.Error())
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误")
		return
	}

	title := dataBody["title"].(string)
	if len(title) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "模块标题不能为空")
		return
	}
	fmt.Println("姓名:",title)
	sort := dataBody["sort"].(string)
	if len(sort) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "排序值不能为空")
		return
	}
	sortt, err := strconv.ParseInt(sort, 10, 64)
	fmt.Println("排序:",sortt)
	introduction := dataBody["introduction"].(string)
	if len(introduction) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "医院介绍不能为空")
		return
	}
	fmt.Println("姓名是什么?",title,"排序是什么",sortt,"医院介绍不能为空",introduction)
	offices := models.SgjPatientOffices{
		Title:        title,
		Sort:         sortt,
		Introduction: introduction,
		UserOrgId:    userOrgID,
		Ctime:        time.Now().Unix(),
	}
	err = site_service.AddOffices(offices)
	if err !=nil{
		this.ServeFailJsonSend(enums.ErrorCodeDataException, "添加医院失败")
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"offices":offices,
	})
}

//添加名医
func (this *Microwebsite) AddDoctor()  {
	adminUserInfo := this.GetAdminUserInfo()
	userOrgID := int64(adminUserInfo.CurrentOrgId)
	dataBody := make(map[string]interface{}, 0)
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &dataBody)
	fmt.Println("错误是什么呢",err)
	fmt.Println("机构ID",userOrgID)
	if err != nil {
		utils.ErrorLog(err.Error())
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误")
		return
	}

	title := dataBody["title"].(string)
	if len(title) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "模块标题不能为空")
		return
	}
	fmt.Println("姓名:",title)
	sort := dataBody["sort"].(string)
	if len(sort) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "排序值不能为空")
		return
	}
	sortt, err := strconv.ParseInt(sort, 10, 64)
	fmt.Println("排序:",sortt)
	image := dataBody["image"].(string)
	if len(image) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "医院介绍不能为空")
		return
	}
	fmt.Println("姓名是什么?",title,"排序是什么",sortt,"医院介绍不能为空",image)

	doctor := models.SgjPatientDoctor{
		Title:  title,
		Sort:   sortt,
		Images: image,
		UserOrgId:userOrgID,
		Ctime:time.Now().Unix(),
	}

	err = site_service.AddDoctor(doctor)
	if err !=nil{
		this.ServeFailJsonSend(enums.ErrorCodeDataException, "添加医院失败")
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"doctor":doctor,
	})
}

//添加名医介绍
func (this *Microwebsite) AddDoctorInfo()  {
	adminUserInfo := this.GetAdminUserInfo()
	userOrgID := int64(adminUserInfo.CurrentOrgId)
	dataBody := make(map[string]interface{}, 0)
	err := json.Unmarshal(this.Ctx.Input.RequestBody, &dataBody)
	fmt.Println("错误是什么呢",err)
	fmt.Println("机构ID",userOrgID)
	if err != nil {
		utils.ErrorLog(err.Error())
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "参数错误")
		return
	}

	docname := dataBody["docname"].(string)
	if len(docname) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "医生姓名不能为空")
		return
	}
	fmt.Println("医生姓名:",docname)
	docHead := dataBody["docHead"].(string)
	if len(docHead) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "医生头像不能为空")
		return
	}
	fmt.Println("医生头像:",docHead)
	docpositional := dataBody["docpositional"].(string)
	if len(docpositional) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "医生职位不能为空")
		return
	}
	fmt.Println("医生职位",docpositional)
	docintroduction := dataBody["docintroduction"].(string)
	fmt.Println("医生简介",docintroduction)
	if len(docintroduction) == 0 {
		this.ServeFailJsonSend(enums.ErrorCodeParamWrong, "医生简介不能为空")
		return
	}
	fmt.Println("医生姓名",docname,"医生职位",docpositional,"医生头像",docHead,"医生简介",docintroduction)
	doctor := models.SgjPatientDoctor{
		Dochead:         docHead,
		Docname:         docname,
		Docintroduction: docintroduction,
		Docpositional:   docpositional,
		UserOrgId:userOrgID,
		Ctime:time.Now().Unix(),
	}
	err = site_service.AddDoctorInfo(doctor)
	if err !=nil{
		this.ServeFailJsonSend(enums.ErrorCodeDataException, "添加医生失败")
		return
	}
	this.ServeSuccessJSON(map[string]interface{}{
		"doctor":doctor,
	})
}